.. include:: links.rst

#######
Credits
#######

BERadio would not have been possible without learning from many others out there.
You know who you are.

We want to say thanks to:

- computourist_ for the `RFM69 based sensors and MQTT gateway`_
  giving us a rough idea where to move.
- `Felix Rusu`_ of LowPowerLab_ fame for conceiving the fine `RFM69 library`_.
- `Jean-Claude Wippler`_ of JeeLabs_ fame for building the `JeeLink v3c`_ (`shop <JeeLink v3c shop>`_),
  a fully assembled and ready-to-use USB "stick" containing an Atmel ATmega328p AVR microprocessor
  and a HopeRF RFM69CW wireless radio module. Also for conceiving the fine EmBencode_ C++ library.
- Weef for suggesting the Bencode_ format.
- Franky for spending two whole afternoons at *Chaos Communication Camp 2015* for
  hunting down and fixing the `EmBencode encoding bug`_ on Arduino_.
- `A Python script to push serial data to MQTT`_
  for getting us started on the MQTT_ side.
  Based on work from `Andy Piper`_ (2011) and `Didier Donsez`_ (2014).
